#!/usr/bin/env node
/*!
 * gitmars v5.1.1-beta.1
 * 这是一个git工作流工具
 * (c) 2021-2023 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import { program } from 'commander';
import sh from 'shelljs';
import chalk from 'chalk';
import { queue } from '@gitmars/core/lib/queue';
import getIsGitProject from '@gitmars/core/lib/git/getIsGitProject';
import { createArgs } from '@gitmars/core/lib/utils/command';
import lang from '#lib/common/local';
import revertConfig from '#lib/conf/revert';

const { t } = lang;
const { red, yellow } = chalk;
const { args, options } = revertConfig;
if (!getIsGitProject()) {
  sh.echo(red(t("The current directory is not a git project directory")));
  process.exit(1);
}
program.name("gitm revert").usage("[commitid] [-n --number [number]] [-m --mode [mode]]").description(t("Undo a commit record"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((commitid, opt) => {
  const cmd = [];
  let n = "HEAD", m = "";
  if (opt.mode)
    m = " -m " + Math.abs(Number(opt.mode));
  if (opt.number) {
    const num = Math.abs(Number(opt.number));
    if (num > 1)
      n += "~" + (num - 1);
    cmd.push({
      cmd: `git revert ${n}${m}`,
      config: {
        again: true,
        success: t("Successfully reverted"),
        fail: t("An error has occurred, please follow the instructions")
      }
    });
  } else if (commitid) {
    cmd.push({
      cmd: `git revert ${commitid}${m}`,
      config: {
        again: true,
        success: t("Successfully reverted"),
        fail: t("An error has occurred, please follow the instructions")
      }
    });
  } else {
    sh.echo(yellow(t("Commands do not meet the specifications")));
    process.exit(1);
  }
  queue(cmd);
});
program.parse(process.argv);
