#!/usr/bin/env node
/*!
 * gitmars v5.1.1-beta.1
 * 这是一个git工作流工具
 * (c) 2021-2023 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
import sh from 'shelljs';
import chalk from 'chalk';
import { program } from 'commander';
import { spawnSync } from '@gitmars/core/lib/spawn';
import { createArgs } from '@gitmars/core/lib/utils/command';
import echo from '@gitmars/core/lib/utils/echo';
import lang from '#lib/common/local';
import uiConfig from '#lib/conf/ui';

const { t } = lang;
const { yellow } = chalk;
const { args, options } = uiConfig;
program.name("gitm ui").usage("[-p --port <port>]").description(t("Link local package"));
if (args.length > 0)
  program.arguments(createArgs(args));
options.forEach((o) => {
  program.option(o.flags, o.description, o.defaultValue);
});
program.action((opt) => {
  const uiBin = sh.which("gitm-ui")?.stdout;
  if (!uiBin) {
    echo(
      yellow(t("Please install the gitm ui plugin first: gitm install @gitmars/ui latest -m"))
    );
    return;
  }
  opt.port && (process.env.PORT = String(opt.port));
  spawnSync("gitm-ui", [], { stdio: "inherit" });
});
program.parse(process.argv);
